==> larus_board-1.1.0.zip: larus_board-1.1.0/setup/update_0.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */

  function xfs_update__10__preparing(){
  return true;
  }

  function xfs_update__10__running(){
    if ( __XF_SQL_ENGINE === 'mysql' ){
    XF::sql_query("ALTER TABLE ".XF::tbl('acl')." CHANGE a_action a_action varchar(32) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('config')." CHANGE c_id c_id varchar(32) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('group')." ADD g_post_filter boolean not null default '0' AFTER g_post_repeat",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." CHANGE l_action l_action varchar(32) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." CHANGE l_ip l_ip varchar(44) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_data')." ADD pd_spam_marker int not null default '0' AFTER pd_time",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_spam int not null default '0' AFTER st_search_cached",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_ham int not null default '0' AFTER st_filter_spam",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('user')." ADD u_uuid char(36) not null default '' AFTER u_active",'',__FILE__,__LINE__);
    }
    elseif ( __XF_SQL_ENGINE === 'pgsql' ){
    XF::sql_query("ALTER TABLE ".XF::tbl('acl')." ALTER a_action TYPE varchar(32)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('config')." ALTER c_id TYPE varchar(32)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('group')." ADD g_post_filter boolean not null default 'false'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." ALTER l_action TYPE varchar(32)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." ALTER l_ip TYPE varchar(44)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." ALTER l_ip SET DEFAULT ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_data')." ADD pd_spam_marker int not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_spam int not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_ham int not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('user')." ADD u_uuid varchar(36) not null default ''",'',__FILE__,__LINE__);
    }
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('cookie_autologin','str'),'value'=>array('lb_autologin','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_enable','str'),'value'=>array('0','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_max_age_ip4','str'),'value'=>array('900','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_max_age_msg','str'),'value'=>array('3600','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_max_age_uid','str'),'value'=>array('86400','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_remote_proxy','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_sink_dnsbl_server','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_sink_local_class','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_sink_local_param','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_size','str'),'value'=>array('50','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_spam_action','str'),'value'=>array('mark','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_threshold','str'),'value'=>array('5','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('http_rewrite_enable','str'),'value'=>array('0','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('http_rewrite_server','str'),'value'=>array('apache','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('mail_signing_class','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('mail_signing_enable','str'),'value'=>array('0','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('mail_signing_param','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("UPDATE ".XF::tbl('group')." SET g_post_filter = :value WHERE g_id = :id",array('id'=>array('1','int'),'value'=>array('1','str')),__FILE__,__LINE__);
  XF::sql_query("UPDATE ".XF::tbl('group')." SET g_post_filter = :value WHERE g_id = :id",array('id'=>array('2','int'),'value'=>array('1','str')),__FILE__,__LINE__);
  xfs_update_add_acl('acp_announcement','exec');
  $suid = XF::sql_query("SELECT u_id FROM ".XF::tbl('user'),'',__FILE__,__LINE__);
    while ( $r = $suid->fetchObject() )
    XF::sql_query("UPDATE ".XF::tbl('user')." SET u_uuid = :uuid WHERE u_id = :id",array('id'=>array($r->u_id,'int'),'uuid'=>array(XF::uuid(),'str')),__FILE__,__LINE__);
  $suid->closeCursor();
  return true;
  }

  function xfs_update__10__cleaning(){
  return true;
  }

?>

==> larus_board-1.1.2.zip: larus_board-1.1.2/setup/update_0.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */

  function xfs_update__10__preparing(){
  return true;
  }

  function xfs_update__10__running(){
    if ( __XF_SQL_ENGINE === 'mysql' ){
    XF::sql_query("ALTER TABLE ".XF::tbl('acl')." CHANGE a_action a_action varchar(32) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('config')." CHANGE c_id c_id varchar(32) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('group')." ADD g_post_filter boolean not null default '0' AFTER g_post_repeat",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." CHANGE l_action l_action varchar(32) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." CHANGE l_ip l_ip varchar(44) not null default ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_data')." ADD pd_spam_marker int not null default '0' AFTER pd_time",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_meta')." ADD p_parent_id int not null default '0' AFTER p_topic_id",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_meta')." ADD p_flags smallint not null default '0' AFTER p_time",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_spam int not null default '0' AFTER st_search_cached",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_ham int not null default '0' AFTER st_filter_spam",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('user')." ADD u_uuid char(36) not null default '' AFTER u_active",'',__FILE__,__LINE__);
    }
    elseif ( __XF_SQL_ENGINE === 'pgsql' ){
    XF::sql_query("ALTER TABLE ".XF::tbl('acl')." ALTER a_action TYPE varchar(32)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('config')." ALTER c_id TYPE varchar(32)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('group')." ADD g_post_filter boolean not null default 'false'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." ALTER l_action TYPE varchar(32)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." ALTER l_ip TYPE varchar(44)",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('log')." ALTER l_ip SET DEFAULT ''",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_data')." ADD pd_spam_marker int not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_meta')." ADD p_parent_id int not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('post_meta')." ADD p_flags smallint not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_spam int not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('statistic')." ADD st_filter_ham int not null default '0'",'',__FILE__,__LINE__);
    XF::sql_query("ALTER TABLE ".XF::tbl('user')." ADD u_uuid varchar(36) not null default ''",'',__FILE__,__LINE__);
    }
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('cookie_autologin','str'),'value'=>array('lb_autologin','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_enable','str'),'value'=>array('0','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_max_age_ip4','str'),'value'=>array('900','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_max_age_msg','str'),'value'=>array('3600','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_max_age_uid','str'),'value'=>array('86400','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_remote_proxy','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_sink_dnsbl_server','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_sink_local_class','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_sink_local_param','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_size','str'),'value'=>array('50','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_spam_action','str'),'value'=>array('mark','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('filter_threshold','str'),'value'=>array('5','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('http_rewrite_enable','str'),'value'=>array('0','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('http_rewrite_server','str'),'value'=>array('apache','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('mail_signing_class','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('mail_signing_enable','str'),'value'=>array('0','str')),__FILE__,__LINE__);
  XF::sql_query("INSERT INTO ".XF::tbl('config')." (c_id,c_value) VALUES (:id,:value)",array('id'=>array('mail_signing_param','str'),'value'=>array('','str')),__FILE__,__LINE__);
  XF::sql_query("UPDATE ".XF::tbl('group')." SET g_post_filter = :value WHERE g_id = :id",array('id'=>array('1','int'),'value'=>array('1','str')),__FILE__,__LINE__);
  XF::sql_query("UPDATE ".XF::tbl('group')." SET g_post_filter = :value WHERE g_id = :id",array('id'=>array('2','int'),'value'=>array('1','str')),__FILE__,__LINE__);
  XF::sql_query("UPDATE ".XF::tbl('post_meta')." SET p_parent_id = p_topic_id WHERE true",'',__FILE__,__LINE__);
  xfs_update_add_acl('acp_announcement','exec');
  xfs_update_add_acl('reset_password','*');
  $suid = XF::sql_query("SELECT u_id FROM ".XF::tbl('user'),'',__FILE__,__LINE__);
    while ( $r = $suid->fetchObject() )
    XF::sql_query("UPDATE ".XF::tbl('user')." SET u_uuid = :uuid WHERE u_id = :id",array('id'=>array($r->u_id,'int'),'uuid'=>array(XF::uuid(),'str')),__FILE__,__LINE__);
  $suid->closeCursor();
  return true;
  }

  function xfs_update__10__cleaning(){
  return true;
  }

?>
